pub struct FileType { /* private fields */ }Available on crate feature
default and non-target_os=unknown only.Expand description
The type of a file or directory.
A file type is returned by Metadata::file_type.
Note that file types are mutually exclusive, i.e. at most one of methods is_dir,
is_file, and is_symlink can return true.
This type is a re-export of std::fs::FileType.
Implementations
Sourceimpl FileType
impl FileType
Sourcepub fn is_dir(&self) -> bool
Available on crate feature docs only.
pub fn is_dir(&self) -> bool
docs only.Returns true if this file type represents a regular directory.
If this file type represents a symbolic link, this method returns false.
Examples
use async_std::fs;
let file_type = fs::metadata(".").await?.file_type();
println!("{:?}", file_type.is_dir());Sourcepub fn is_file(&self) -> bool
Available on crate feature docs only.
pub fn is_file(&self) -> bool
docs only.Returns true if this file type represents a regular file.
If this file type represents a symbolic link, this method returns false.
Examples
use async_std::fs;
let file_type = fs::metadata("a.txt").await?.file_type();
println!("{:?}", file_type.is_file());Sourcepub fn is_symlink(&self) -> bool
Available on crate feature docs only.
pub fn is_symlink(&self) -> bool
docs only.Returns true if this file type represents a symbolic link.
Examples
use async_std::fs;
let file_type = fs::metadata("a.txt").await?.file_type();
println!("{:?}", file_type.is_symlink());Trait Implementations
impl Copy for FileType
impl Eq for FileType
impl StructuralPartialEq for FileType