Chain

Struct Chain 

pub struct Chain<T, U> { /* private fields */ }
Available on crate feature std only.
Adaptor to chain together two readers.

This struct is generally created by calling chain on a reader. Please see the documentation of chain for more details.

Implementations

Source

impl<T, U> Chain<T, U>

pub fn into_inner(self) -> (T, U)

Consumes the Chain, returning the wrapped readers.

Examples
use async_std::prelude::*;
use async_std::fs::File;

let foo_file = File::open("foo.txt").await?;
let bar_file = File::open("bar.txt").await?;

let chain = foo_file.chain(bar_file);
let (foo_file, bar_file) = chain.into_inner();
pub fn get_ref(&self) -> (&T, &U)

Gets references to the underlying readers in this Chain.

Examples
use async_std::prelude::*;
use async_std::fs::File;

let foo_file = File::open("foo.txt").await?;
let bar_file = File::open("bar.txt").await?;

let chain = foo_file.chain(bar_file);
let (foo_file, bar_file) = chain.get_ref();
pub fn get_mut(&mut self) -> (&mut T, &mut U)

Gets mutable references to the underlying readers in this Chain.

Care should be taken to avoid modifying the internal I/O state of the underlying readers as doing so may corrupt the internal state of this Chain.

Examples
use async_std::prelude::*;
use async_std::fs::File;

let foo_file = File::open("foo.txt").await?;
let bar_file = File::open("bar.txt").await?;

let mut chain = foo_file.chain(bar_file);
let (foo_file, bar_file) = chain.get_mut();