Cursor

Struct Cursor 

pub struct Cursor<T> { /* private fields */ }
Available on crate feature std only.
A Cursor wraps an in-memory buffer and provides it with a Seek implementation.

Cursors are used with in-memory buffers, anything implementing AsRef<[u8]>, to allow them to implement Read and/or Write, allowing these buffers to be used anywhere you might use a reader or writer that does actual I/O.

The standard library implements some I/O traits on various types which are commonly used as a buffer, like Cursor<Vec<u8>> and Cursor<&[u8]>.

Implementations

Source

impl<T> Cursor<T>

pub fn new(inner: T) -> Cursor<T>

Creates a new cursor wrapping the provided underlying in-memory buffer.

Cursor initial position is 0 even if underlying buffer (e.g., Vec) is not empty. So writing to cursor starts with overwriting Vec content, not with appending to it.

Examples
use async_std::io::Cursor;

let buff = Cursor::new(Vec::new());
pub fn into_inner(self) -> T

Consumes this cursor, returning the underlying value.

Examples
use async_std::io::Cursor;

let buff = Cursor::new(Vec::new());

let vec = buff.into_inner();
pub fn get_ref(&self) -> &T

Gets a reference to the underlying value in this cursor.

Examples
use async_std::io::Cursor;

let buff = Cursor::new(Vec::new());

let reference = buff.get_ref();
pub fn get_mut(&mut self) -> &mut T

Gets a mutable reference to the underlying value in this cursor.

Care should be taken to avoid modifying the internal I/O state of the underlying value as it may corrupt this cursor’s position.

Examples
use async_std::io::Cursor;

let mut buff = Cursor::new(Vec::new());

let reference = buff.get_mut();
pub fn position(&self) -> u64

Returns the current position of this cursor.

Examples
use async_std::io::Cursor;
use async_std::io::prelude::*;
use async_std::io::SeekFrom;

let mut buff = Cursor::new(vec![1, 2, 3, 4, 5]);

assert_eq!(buff.position(), 0);

buff.seek(SeekFrom::Current(2)).await?;
assert_eq!(buff.position(), 2);

buff.seek(SeekFrom::Current(-1)).await?;
assert_eq!(buff.position(), 1);
pub fn set_position(&mut self, pos: u64)

Sets the position of this cursor.

Examples
use async_std::io::Cursor;

let mut buff = Cursor::new(vec![1, 2, 3, 4, 5]);

assert_eq!(buff.position(), 0);

buff.set_position(2);
assert_eq!(buff.position(), 2);

buff.set_position(4);
assert_eq!(buff.position(), 4);