Module io

Module io 

Available on crate feature std and (Unix or crate feature docs) only.
Unix-specific I/O extensions.

Traits

AsRawFddocs
A trait to extract the raw unix file descriptor from an underlying object.
FromRawFddocs
A trait to express the ability to construct an object from a raw file descriptor.
IntoRawFddocs
A trait to express the ability to consume an object and acquire ownership of its raw file descriptor.

Type Aliases

RawFddocs
Raw file descriptors.