AsRawFd

Trait AsRawFd 

1.0.0 · Source
pub trait AsRawFd {
    // Required method
    fn as_raw_fd(&self) -> i32;
}
A trait to extract the raw file descriptor from an underlying object.

This is only available on unix and WASI platforms and must be imported in order to call the method. Windows platforms have a corresponding AsRawHandle and AsRawSocket set of traits.

Required Methods

1.0.0 · Source

fn as_raw_fd(&self) -> i32

Extracts the raw file descriptor.

This function is typically used to borrow an owned file descriptor. When used in this way, this method does not pass ownership of the raw file descriptor to the caller, and the file descriptor is only guaranteed to be valid while the original object has not yet been destroyed.

However, borrowing is not strictly required. See [AsFd::as_fd] for an API which strictly borrows a file descriptor.

Example
use std::fs::File;
#[cfg(any(unix, target_os = "wasi"))]
use std::os::fd::{AsRawFd, RawFd};

let mut f = File::open("foo.txt")?;
// Note that `raw_fd` is only valid as long as `f` exists.
#[cfg(any(unix, target_os = "wasi"))]
let raw_fd: RawFd = f.as_raw_fd();

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.63.0 · Source

impl AsRawFd for BorrowedFd<'_>

1.2.0 · Source

impl AsRawFd for std::process::ChildStderr

Source

impl AsRawFd for async_std::process::ChildStderr

Available on Unix only.
1.2.0 · Source

impl AsRawFd for std::process::ChildStdin

Source

impl AsRawFd for async_std::process::ChildStdin

Available on Unix only.
1.2.0 · Source

impl AsRawFd for std::process::ChildStdout

Source

impl AsRawFd for async_std::process::ChildStdout

Available on Unix only.
Source

impl AsRawFd for Dir

1.0.0 · Source

impl AsRawFd for std::fs::File

Available on non-Trusty only.
Source

impl AsRawFd for async_std::fs::File

Available on Unix or crate feature docs only.
1.63.0 · Source

impl AsRawFd for OwnedFd

Source

impl AsRawFd for PidFd

1.87.0 · Source

impl AsRawFd for PipeReader

Available on non-Trusty only.
1.87.0 · Source

impl AsRawFd for PipeWriter

Available on non-Trusty only.
Source

impl AsRawFd for Poller

Source

impl AsRawFd for Signals

Available on Unix only.
1.21.0 · Source

impl AsRawFd for std::io::stdio::Stderr

Source

impl AsRawFd for async_std::io::Stderr

Available on Unix or crate feature docs only.
1.21.0 · Source

impl AsRawFd for std::io::stdio::Stdin

Available on non-Trusty only.
Source

impl AsRawFd for async_std::io::Stdin

Available on Unix or crate feature docs only.
1.21.0 · Source

impl AsRawFd for std::io::stdio::Stdout

Source

impl AsRawFd for async_std::io::Stdout

Available on Unix or crate feature docs only.
1.0.0 · Source

impl AsRawFd for std::net::tcp::TcpListener

Source

impl AsRawFd for async_std::net::TcpListener

Available on Unix or crate feature docs only.
1.0.0 · Source

impl AsRawFd for std::net::tcp::TcpStream

Source

impl AsRawFd for async_std::net::TcpStream

Available on Unix or crate feature docs only.
1.0.0 · Source

impl AsRawFd for std::net::udp::UdpSocket

Source

impl AsRawFd for async_std::net::UdpSocket

Available on Unix or crate feature docs only.
1.10.0 · Source

impl AsRawFd for std::os::unix::net::datagram::UnixDatagram

Source

impl AsRawFd for async_std::os::unix::net::UnixDatagram

1.10.0 · Source

impl AsRawFd for std::os::unix::net::listener::UnixListener

Source

impl AsRawFd for async_std::os::unix::net::UnixListener

1.10.0 · Source

impl AsRawFd for std::os::unix::net::stream::UnixStream

Source

impl AsRawFd for async_std::os::unix::net::UnixStream

1.48.0 · Source

impl AsRawFd for i32

1.35.0 · Source

impl<'a> AsRawFd for StderrLock<'a>

1.35.0 · Source

impl<'a> AsRawFd for StdinLock<'a>

Available on non-Trusty only.
1.35.0 · Source

impl<'a> AsRawFd for StdoutLock<'a>

1.63.0 · Source

impl<T> AsRawFd for Arc<T>
where T: AsRawFd,

This impl allows implementing traits that require AsRawFd on Arc.

use std::net::UdpSocket;
use std::sync::Arc;
trait MyTrait: AsRawFd {
}
impl MyTrait for Arc<UdpSocket> {}
impl MyTrait for Box<UdpSocket> {}
Source

impl<T> AsRawFd for Async<T>
where T: AsRawFd,

Available on Unix only.
1.63.0 · Source

impl<T> AsRawFd for Box<T>
where T: AsRawFd,

1.69.0 · Source

impl<T> AsRawFd for Rc<T>
where T: AsRawFd,

Source

impl<T> AsRawFd for UniqueRc<T>
where T: AsRawFd + ?Sized,