pub trait IntoRawFd {
// Required method
fn into_raw_fd(self) -> i32;
}Expand description
A trait to express the ability to consume an object and acquire ownership of its raw file descriptor.
Required Methods
1.4.0 · Sourcefn into_raw_fd(self) -> i32
fn into_raw_fd(self) -> i32
Consumes this object, returning the raw underlying file descriptor.
This function is typically used to transfer ownership of the underlying file descriptor to the caller. When used in this way, callers are then the unique owners of the file descriptor and must close it once it’s no longer needed.
However, transferring ownership is not strictly required. Use a
Into<OwnedFd>::into implementation for an API which strictly
transfers ownership.
Example
use std::fs::File;
#[cfg(any(unix, target_os = "wasi"))]
use std::os::fd::{IntoRawFd, RawFd};
let f = File::open("foo.txt")?;
#[cfg(any(unix, target_os = "wasi"))]
let raw_fd: RawFd = f.into_raw_fd();Implementors
impl IntoRawFd for i32
impl IntoRawFd for async_std::fs::File
Available on Unix or crate feature
docs only.impl IntoRawFd for async_std::net::TcpListener
Available on Unix or crate feature
docs only.impl IntoRawFd for async_std::net::TcpStream
Available on Unix or crate feature
docs only.impl IntoRawFd for async_std::net::UdpSocket
Available on Unix or crate feature
docs only.impl IntoRawFd for async_std::os::unix::net::UnixDatagram
impl IntoRawFd for async_std::os::unix::net::UnixListener
impl IntoRawFd for async_std::os::unix::net::UnixStream
impl IntoRawFd for Dir
impl IntoRawFd for std::fs::File
Available on non-Trusty only.
impl IntoRawFd for PipeReader
Available on non-Trusty only.
impl IntoRawFd for PipeWriter
Available on non-Trusty only.