Module io

Module io 

Available on crate feature std and (Windows or crate feature docs) only.
Windows-specific I/O extensions.

Traits

AsRawHandledocs
Extracts raw handles.
AsRawSocketdocs
Extracts raw sockets.
FromRawHandledocs
Construct I/O objects from raw handles.
FromRawSocketdocs
Creates I/O objects from raw sockets.
IntoRawHandledocs
A trait to express the ability to consume an object and acquire ownership of its raw HANDLE.
IntoRawSocketdocs
A trait to express the ability to consume an object and acquire ownership of its raw SOCKET.

Type Aliases

RawHandledocs
Raw HANDLEs.
RawSocketdocs
Raw SOCKETs.