FromRawSocket

Trait FromRawSocket 

pub trait FromRawSocket {
    // Required method
    unsafe fn from_raw_socket(sock: RawSocket) -> Self;
}
Available on crate feature docs and crate feature std and (Windows or crate feature docs) only.
Creates I/O objects from raw sockets.

Required Methods

unsafe fn from_raw_socket(sock: RawSocket) -> Self

Creates a new I/O object from the given raw socket.

This function will consume ownership of the socket provided and it will be closed when the returned object goes out of scope.

This function is also unsafe as the primitives currently returned have the contract that they are the sole owner of the file descriptor they are wrapping. Usage of this function could accidentally allow violating this contract which can cause memory unsafety in code that relies on it being true.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl FromRawSocket for TcpListener

Available on crate feature default and non-target_os=unknown only.
Source

impl FromRawSocket for TcpStream

Available on crate feature default and non-target_os=unknown only.
Source

impl FromRawSocket for UdpSocket

Available on crate feature default and non-target_os=unknown only.