pub trait IntoRawHandle {
// Required method
fn into_raw_handle(self) -> RawHandle;
}Available on crate feature
docs and crate feature std and (Windows or crate feature docs) only.Expand description
A trait to express the ability to consume an object and acquire ownership of
its raw HANDLE.
Required Methods
Sourcefn into_raw_handle(self) -> RawHandle
fn into_raw_handle(self) -> RawHandle
Consumes this object, returning the raw underlying handle.
This function transfers ownership of the underlying handle to the caller. Callers are then the unique owners of the handle and must close it once it’s no longer needed.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl IntoRawHandle for File
Available on crate feature
default and non-target_os=unknown only.