macro_rules! ready {
($e:expr $(,)?) => { ... };
}Available on crate feature
std only.Expand description
Extracts the successful type of a Poll<T>.
This macro bakes in propagation of Pending signals by returning early.
Extracts the successful type of a Poll<T>.
This macro bakes in propagation of Pending signals by returning early.