Metadata

Struct Metadata 

pub struct Metadata { /* private fields */ }
Available on crate feature default and non-target_os=unknown only.
Metadata for a file or directory.

Metadata is returned by metadata and symlink_metadata.

This type is a re-export of std::fs::Metadata.

Implementations

Source

impl Metadata

pub fn file_type(&self) -> FileType

Available on crate feature docs only.

Returns the file type from this metadata.

Examples
use async_std::fs;

let metadata = fs::metadata("a.txt").await?;
println!("{:?}", metadata.file_type());
pub fn is_dir(&self) -> bool

Available on crate feature docs only.

Returns true if this metadata is for a regular directory.

If this metadata is for a symbolic link, this method returns false.

Examples
use async_std::fs;

let metadata = fs::metadata(".").await?;
println!("{:?}", metadata.is_dir());
pub fn is_file(&self) -> bool

Available on crate feature docs only.

Returns true if this metadata is for a regular file.

If this metadata is for a symbolic link, this method returns false.

Examples
use async_std::fs;

let metadata = fs::metadata("a.txt").await?;
println!("{:?}", metadata.is_file());
pub fn len(&self) -> u64

Available on crate feature docs only.

Returns the file size in bytes.

Examples
use async_std::fs;

let metadata = fs::metadata("a.txt").await?;
println!("{}", metadata.len());
pub fn permissions(&self) -> Permissions

Available on crate feature docs only.

Returns the permissions from this metadata.

Examples
use async_std::fs;

let metadata = fs::metadata("a.txt").await?;
println!("{:?}", metadata.permissions());
pub fn modified(&self) -> Result<SystemTime>

Available on crate feature docs only.

Returns the last modification time.

Errors

This data may not be available on all platforms, in which case an error will be returned.

Examples
use async_std::fs;

let metadata = fs::metadata("a.txt").await?;
println!("{:?}", metadata.modified());
pub fn accessed(&self) -> Result<SystemTime>

Available on crate feature docs only.

Returns the last access time.

Errors

This data may not be available on all platforms, in which case an error will be returned.

Examples
use async_std::fs;

let metadata = fs::metadata("a.txt").await?;
println!("{:?}", metadata.accessed());
pub fn created(&self) -> Result<SystemTime>

Available on crate feature docs only.

Returns the creation time.

Errors

This data may not be available on all platforms, in which case an error will be returned.

Examples
use async_std::fs;

let metadata = fs::metadata("a.txt").await?;
println!("{:?}", metadata.created());