Available on crate feature
std and (Windows or crate feature docs) only.Expand description
Windows-specific I/O extensions.
Traits
- AsRaw
Handle docs - Extracts raw handles.
- AsRaw
Socket docs - Extracts raw sockets.
- From
RawHandle docs - Construct I/O objects from raw handles.
- From
RawSocket docs - Creates I/O objects from raw sockets.
- Into
RawHandle docs - A trait to express the ability to consume an object and acquire ownership of
its raw
HANDLE. - Into
RawSocket docs - A trait to express the ability to consume an object and acquire ownership of
its raw
SOCKET.