IntoRawHandle

Trait IntoRawHandle 

pub trait IntoRawHandle {
    // Required method
    fn into_raw_handle(self) -> RawHandle;
}
Available on crate feature std and (Windows or crate feature docs) and crate feature docs only.
A trait to express the ability to consume an object and acquire ownership of its raw HANDLE.

Required Methods

fn into_raw_handle(self) -> RawHandle

Consumes this object, returning the raw underlying handle.

This function transfers ownership of the underlying handle to the caller. Callers are then the unique owners of the handle and must close it once it’s no longer needed.

Implementors

Source

impl IntoRawHandle for File

Available on crate feature default and non-target_os=unknown only.