pub trait IntoRawSocket {
// Required method
fn into_raw_socket(self) -> RawSocket;
}Available on crate feature
docs and crate feature std and (Windows or crate feature docs) only.Expand description
A trait to express the ability to consume an object and acquire ownership of
its raw SOCKET.
Required Methods
Sourcefn into_raw_socket(self) -> RawSocket
fn into_raw_socket(self) -> RawSocket
Consumes this object, returning the raw underlying socket.
This function transfers ownership of the underlying socket to the caller. Callers are then the unique owners of the socket and must close it once it’s no longer needed.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl IntoRawSocket for TcpListener
Available on crate feature
default and non-target_os=unknown only.impl IntoRawSocket for TcpStream
Available on crate feature
default and non-target_os=unknown only.impl IntoRawSocket for UdpSocket
Available on crate feature
default and non-target_os=unknown only.