pub trait IntoRawSocket {
// Required method
fn into_raw_socket(self) -> RawSocket;
}Available on crate feature
std and (Windows or crate feature docs) and crate feature docs only.Expand description
A trait to express the ability to consume an object and acquire ownership of
its raw SOCKET.
Required Methods
Sourcefn into_raw_socket(self) -> RawSocket
fn into_raw_socket(self) -> RawSocket
Consumes this object, returning the raw underlying socket.
This function transfers ownership of the underlying socket to the caller. Callers are then the unique owners of the socket and must close it once it’s no longer needed.
Implementors
impl IntoRawSocket for TcpListener
Available on non-
target_os=unknown and crate feature default only.impl IntoRawSocket for TcpStream
Available on non-
target_os=unknown and crate feature default only.impl IntoRawSocket for UdpSocket
Available on non-
target_os=unknown and crate feature default only.