ready

Macro ready 

macro_rules! ready {
    ($e:expr $(,)?) => { ... };
}
Available on crate feature alloc only.
Extracts the successful type of a Poll<T>.

This macro bakes in propagation of Pending signals by returning early. Extracts the successful type of Poll<T>.

This macro bakes in propagation of Pending signals by returning early.

Note: Since Rust 1.64, this macro is soft-deprecated in favor of ready! macro in the standard library.